@@ -7,9 +7,8 @@
 import os
 import sys
 import signal
-from base import Base
+from .base import Base
 from ...machine import Machine
-import armcncio as armcncio_file
 
 class Init:
 
@@ -24,23 +23,19 @@ class Init:
     def start(self):
         if len(sys.argv) > 0 and sys.argv[0] != "":
             self.coordinates = sys.argv[0]
-            on_start = "on_start"
-            if on_start in dir(armcncio_file):
-                var_name = "MACHINE_PATH"
-                if var_name in os.environ:
-                    env_var = os.environ[var_name]
-                    if env_var != "":
-                        self.machine.machine_path = env_var
-                        print(self.machine.machine_path, self.coordinates)
-                getattr(armcncio_file, on_start)(self)
+            var_name = "MACHINE_PATH"
+            if var_name in os.environ:
+                env_var = os.environ[var_name]
+                if env_var != "":
+                    self.machine.machine_path = env_var
+                    self.base.setup()
+                    while True:
+                        self.base.loop()
             self.signal_handler(False, False)
 
     def signal_handler(self, signum, frame):
-        on_exit = "on_exit"
         if self.base.hal:
             self.base.hal.exit()
         if self.base.gpio:
             self.base.gpio.cleanup()
-        if on_exit in dir(armcncio_file):
-            getattr(armcncio_file, on_exit)(self)
         sys.exit()
